@@ -3,8 +3,9 @@
 
 #include <QDialog>
 
-namespace Ui {
-    class Dialog;
+namespace Ui
+{
+class Dialog;
 }
 
 class Dialog : public QDialog
