@@ -12,9 +12,10 @@ int main(int argc, char *argv[])
     return a.exec();
 #else
     PWQDialog pwdDialog;
-    if (pwdDialog.exec()==PWQDialog::Accepted) {
-    w.show();
-    return a.exec();
+    if (pwdDialog.exec()==PWQDialog::Accepted)
+    {
+        w.show();
+        return a.exec();
     }
     else a.quit();
 #endif
