@@ -39,6 +39,7 @@ private slots:
     void save_ini();
     void load_ini();
     void wload_ini();
+    void btload_ini();
     void checkbootfile();
     void on_pushButton_rulenow_clicked();
     void on_listWidget_real_doubleClicked(QModelIndex index);
@@ -89,13 +90,14 @@ private slots:
     void on_pushButton_loadloport_clicked();
     void on_pushButton_saveloport_clicked();
     void checkwmode();
+    void checkbtmode();
     void wifistatus();
     bool checkmodule(QString nmodule);
     bool checkdnsmasq();
+    bool getBTstatus();
     int cuttercount(QString row);
     int cutterint(QString row, int place);
     QString getBTproperty(QString key);
-    QString getBTname();
     QString getBTdevPath();
     QString getlsof();
     QString write_filter(QString);
@@ -106,6 +108,7 @@ private slots:
     QString getfilter(QString ftype);
     QString getpidof(QString pname);
     void sshstatus();
+    void sshinfo();
     void getrev();
     void getimei();
     void getimsi();
@@ -140,7 +143,7 @@ private slots:
     void on_pushButton_sshstartstop_clicked();
     void on_pushButton_btsave_clicked();
     void on_pushButton_btonoff_clicked();
-    void on_pushButton_btstartstop_clicked();
+    void on_pushButton_btstart_clicked();
     void on_pushButton_delboot_clicked();
     void on_pushButton_addblackip_clicked();
     void on_pushButton_rmblackip_clicked();
@@ -168,6 +171,10 @@ private slots:
     void on_pushButton_loadfile_clicked();
     void on_pushButton_blhostappend_clicked();
     void on_pushButton_blhostdown_clicked();
+    void on_pushButton_sshkillpid_clicked();
+    void on_checkBox_btdiscover_stateChanged(int state);
+    void on_pushButton_bridge_clicked();
+    void on_pushButton_btstop_clicked();
 };
 
 #endif // MAINWINDOW_H
