@@ -3,8 +3,9 @@
 
 #include <QDialog>
 
-namespace Ui {
-    class PWDialog;
+namespace Ui
+{
+class PWDialog;
 }
 class PWDialog : public QDialog
 {
